@@ -512,6 +512,15 @@ oneLtPowSubst = go
     go :: 1 <= b => Proxy a -> Proxy a
     go = id
 
+isOkay ::
+  forall x y sh .
+  Proxy x ->
+  Proxy y ->
+  Proxy sh ->
+  Proxy (Drop (x + y) sh) ->
+  Proxy (Drop (y + x) sh)
+isOkay _ _ _ px = px
+
 main :: IO ()
 main = defaultMain tests
 
@@ -556,6 +565,9 @@ tests = testGroup "ghc-typelits-natnormalise"
     , testCase "(((2 ^ x) - 2) * (2 ^ (x + x))) ~ ((2 ^ ((x + (x + x)) - 1)) + ((2 ^ ((x + (x + x)) - 1)) - (2 ^ ((x + x) + 1))))" $
       show (proxyEq2 @2 Proxy) @?=
       "Proxy"
+    , testCase "Unify in non-injective positions under specific conditions" $
+      show (isOkay @2 @3 @'[] Proxy Proxy Proxy Proxy) @?=
+      "Proxy"
     ]
   , testGroup "Implications"
     [ testCase "(x + 1) ~ (2 * y)) implies (((2 * (y - 1)) + 1)) ~ x" $
